@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -51,6 +53,13 @@ class AccessGroup(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.VpcType = params.get("VpcType")
         self.VpcId = params.get("VpcId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AccessRule(AbstractModel):
@@ -84,6 +93,13 @@ class AccessRule(AbstractModel):
         self.AccessMode = params.get("AccessMode")
         self.Priority = params.get("Priority")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AssociateAccessGroupsRequest(AbstractModel):
@@ -105,6 +121,13 @@ class AssociateAccessGroupsRequest(AbstractModel):
     def _deserialize(self, params):
         self.MountPointId = params.get("MountPointId")
         self.AccessGroupIds = params.get("AccessGroupIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AssociateAccessGroupsResponse(AbstractModel):
@@ -122,6 +145,13 @@ class AssociateAccessGroupsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAccessGroupRequest(AbstractModel):
@@ -151,6 +181,13 @@ class CreateAccessGroupRequest(AbstractModel):
         self.VpcType = params.get("VpcType")
         self.VpcId = params.get("VpcId")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAccessGroupResponse(AbstractModel):
@@ -174,6 +211,13 @@ class CreateAccessGroupResponse(AbstractModel):
             self.AccessGroup = AccessGroup()
             self.AccessGroup._deserialize(params.get("AccessGroup"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAccessRulesRequest(AbstractModel):
@@ -200,6 +244,13 @@ class CreateAccessRulesRequest(AbstractModel):
                 obj._deserialize(item)
                 self.AccessRules.append(obj)
         self.AccessGroupId = params.get("AccessGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAccessRulesResponse(AbstractModel):
@@ -217,6 +268,13 @@ class CreateAccessRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateFileSystemRequest(AbstractModel):
@@ -258,6 +316,13 @@ class CreateFileSystemRequest(AbstractModel):
         self.SuperUsers = params.get("SuperUsers")
         self.RootInodeUser = params.get("RootInodeUser")
         self.RootInodeGroup = params.get("RootInodeGroup")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateFileSystemResponse(AbstractModel):
@@ -281,6 +346,13 @@ class CreateFileSystemResponse(AbstractModel):
             self.FileSystem = FileSystem()
             self.FileSystem._deserialize(params.get("FileSystem"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateLifeCycleRulesRequest(AbstractModel):
@@ -307,6 +379,13 @@ class CreateLifeCycleRulesRequest(AbstractModel):
                 obj = LifeCycleRule()
                 obj._deserialize(item)
                 self.LifeCycleRules.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateLifeCycleRulesResponse(AbstractModel):
@@ -324,6 +403,13 @@ class CreateLifeCycleRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateMountPointRequest(AbstractModel):
@@ -349,6 +435,13 @@ class CreateMountPointRequest(AbstractModel):
         self.MountPointName = params.get("MountPointName")
         self.FileSystemId = params.get("FileSystemId")
         self.MountPointStatus = params.get("MountPointStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateMountPointResponse(AbstractModel):
@@ -372,6 +465,13 @@ class CreateMountPointResponse(AbstractModel):
             self.MountPoint = MountPoint()
             self.MountPoint._deserialize(params.get("MountPoint"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateRestoreTasksRequest(AbstractModel):
@@ -398,6 +498,13 @@ class CreateRestoreTasksRequest(AbstractModel):
                 obj = RestoreTask()
                 obj._deserialize(item)
                 self.RestoreTasks.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateRestoreTasksResponse(AbstractModel):
@@ -415,6 +522,13 @@ class CreateRestoreTasksResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAccessGroupRequest(AbstractModel):
@@ -432,6 +546,13 @@ class DeleteAccessGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessGroupId = params.get("AccessGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAccessGroupResponse(AbstractModel):
@@ -449,6 +570,13 @@ class DeleteAccessGroupResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAccessRulesRequest(AbstractModel):
@@ -466,6 +594,13 @@ class DeleteAccessRulesRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessRuleIds = params.get("AccessRuleIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAccessRulesResponse(AbstractModel):
@@ -483,6 +618,13 @@ class DeleteAccessRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteFileSystemRequest(AbstractModel):
@@ -500,6 +642,13 @@ class DeleteFileSystemRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FileSystemId = params.get("FileSystemId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteFileSystemResponse(AbstractModel):
@@ -517,6 +666,13 @@ class DeleteFileSystemResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteLifeCycleRulesRequest(AbstractModel):
@@ -534,6 +690,13 @@ class DeleteLifeCycleRulesRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.LifeCycleRuleIds = params.get("LifeCycleRuleIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteLifeCycleRulesResponse(AbstractModel):
@@ -551,6 +714,13 @@ class DeleteLifeCycleRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteMountPointRequest(AbstractModel):
@@ -568,6 +738,13 @@ class DeleteMountPointRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.MountPointId = params.get("MountPointId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteMountPointResponse(AbstractModel):
@@ -585,6 +762,13 @@ class DeleteMountPointResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessGroupRequest(AbstractModel):
@@ -602,6 +786,13 @@ class DescribeAccessGroupRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessGroupId = params.get("AccessGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessGroupResponse(AbstractModel):
@@ -625,6 +816,13 @@ class DescribeAccessGroupResponse(AbstractModel):
             self.AccessGroup = AccessGroup()
             self.AccessGroup._deserialize(params.get("AccessGroup"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessGroupsRequest(AbstractModel):
@@ -647,6 +845,13 @@ class DescribeAccessGroupsRequest(AbstractModel):
     def _deserialize(self, params):
         self.VpcId = params.get("VpcId")
         self.OwnerUin = params.get("OwnerUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessGroupsResponse(AbstractModel):
@@ -673,6 +878,13 @@ class DescribeAccessGroupsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.AccessGroups.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessRulesRequest(AbstractModel):
@@ -690,6 +902,13 @@ class DescribeAccessRulesRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessGroupId = params.get("AccessGroupId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAccessRulesResponse(AbstractModel):
@@ -716,6 +935,13 @@ class DescribeAccessRulesResponse(AbstractModel):
                 obj._deserialize(item)
                 self.AccessRules.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeFileSystemRequest(AbstractModel):
@@ -733,6 +959,13 @@ class DescribeFileSystemRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FileSystemId = params.get("FileSystemId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeFileSystemResponse(AbstractModel):
@@ -766,6 +999,13 @@ class DescribeFileSystemResponse(AbstractModel):
         self.CapacityUsed = params.get("CapacityUsed")
         self.ArchiveCapacityUsed = params.get("ArchiveCapacityUsed")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeFileSystemsRequest(AbstractModel):
@@ -798,6 +1038,13 @@ class DescribeFileSystemsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.FileSystems.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeLifeCycleRulesRequest(AbstractModel):
@@ -815,6 +1062,13 @@ class DescribeLifeCycleRulesRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FileSystemId = params.get("FileSystemId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeLifeCycleRulesResponse(AbstractModel):
@@ -841,6 +1095,13 @@ class DescribeLifeCycleRulesResponse(AbstractModel):
                 obj._deserialize(item)
                 self.LifeCycleRules.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeMountPointRequest(AbstractModel):
@@ -858,6 +1119,13 @@ class DescribeMountPointRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.MountPointId = params.get("MountPointId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeMountPointResponse(AbstractModel):
@@ -881,6 +1149,13 @@ class DescribeMountPointResponse(AbstractModel):
             self.MountPoint = MountPoint()
             self.MountPoint._deserialize(params.get("MountPoint"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeMountPointsRequest(AbstractModel):
@@ -907,6 +1182,13 @@ class DescribeMountPointsRequest(AbstractModel):
         self.FileSystemId = params.get("FileSystemId")
         self.AccessGroupId = params.get("AccessGroupId")
         self.OwnerUin = params.get("OwnerUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeMountPointsResponse(AbstractModel):
@@ -933,6 +1215,13 @@ class DescribeMountPointsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.MountPoints.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeResourceTagsRequest(AbstractModel):
@@ -950,6 +1239,13 @@ class DescribeResourceTagsRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FileSystemId = params.get("FileSystemId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeResourceTagsResponse(AbstractModel):
@@ -976,6 +1272,13 @@ class DescribeResourceTagsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Tags.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeRestoreTasksRequest(AbstractModel):
@@ -993,6 +1296,13 @@ class DescribeRestoreTasksRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FileSystemId = params.get("FileSystemId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeRestoreTasksResponse(AbstractModel):
@@ -1019,6 +1329,13 @@ class DescribeRestoreTasksResponse(AbstractModel):
                 obj._deserialize(item)
                 self.RestoreTasks.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DisassociateAccessGroupsRequest(AbstractModel):
@@ -1040,6 +1357,13 @@ class DisassociateAccessGroupsRequest(AbstractModel):
     def _deserialize(self, params):
         self.MountPointId = params.get("MountPointId")
         self.AccessGroupIds = params.get("AccessGroupIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DisassociateAccessGroupsResponse(AbstractModel):
@@ -1057,6 +1381,13 @@ class DisassociateAccessGroupsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class FileSystem(AbstractModel):
@@ -1114,6 +1445,13 @@ class FileSystem(AbstractModel):
         self.Status = params.get("Status")
         self.SuperUsers = params.get("SuperUsers")
         self.PosixAcl = params.get("PosixAcl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class LifeCycleRule(AbstractModel):
@@ -1156,6 +1494,13 @@ class LifeCycleRule(AbstractModel):
                 self.Transitions.append(obj)
         self.Status = params.get("Status")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyAccessGroupRequest(AbstractModel):
@@ -1181,6 +1526,13 @@ class ModifyAccessGroupRequest(AbstractModel):
         self.AccessGroupId = params.get("AccessGroupId")
         self.AccessGroupName = params.get("AccessGroupName")
         self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyAccessGroupResponse(AbstractModel):
@@ -1198,6 +1550,13 @@ class ModifyAccessGroupResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyAccessRulesRequest(AbstractModel):
@@ -1220,6 +1579,13 @@ class ModifyAccessRulesRequest(AbstractModel):
                 obj = AccessRule()
                 obj._deserialize(item)
                 self.AccessRules.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyAccessRulesResponse(AbstractModel):
@@ -1237,6 +1603,13 @@ class ModifyAccessRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyFileSystemRequest(AbstractModel):
@@ -1275,6 +1648,13 @@ class ModifyFileSystemRequest(AbstractModel):
         self.CapacityQuota = params.get("CapacityQuota")
         self.SuperUsers = params.get("SuperUsers")
         self.PosixAcl = params.get("PosixAcl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyFileSystemResponse(AbstractModel):
@@ -1292,6 +1672,13 @@ class ModifyFileSystemResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyLifeCycleRulesRequest(AbstractModel):
@@ -1314,6 +1701,13 @@ class ModifyLifeCycleRulesRequest(AbstractModel):
                 obj = LifeCycleRule()
                 obj._deserialize(item)
                 self.LifeCycleRules.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyLifeCycleRulesResponse(AbstractModel):
@@ -1331,6 +1725,13 @@ class ModifyLifeCycleRulesResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyMountPointRequest(AbstractModel):
@@ -1356,6 +1757,13 @@ class ModifyMountPointRequest(AbstractModel):
         self.MountPointId = params.get("MountPointId")
         self.MountPointName = params.get("MountPointName")
         self.MountPointStatus = params.get("MountPointStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyMountPointResponse(AbstractModel):
@@ -1373,6 +1781,13 @@ class ModifyMountPointResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyResourceTagsRequest(AbstractModel):
@@ -1399,6 +1814,13 @@ class ModifyResourceTagsRequest(AbstractModel):
                 obj = Tag()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyResourceTagsResponse(AbstractModel):
@@ -1416,6 +1838,13 @@ class ModifyResourceTagsResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class MountPoint(AbstractModel):
@@ -1453,6 +1882,13 @@ class MountPoint(AbstractModel):
         self.Status = params.get("Status")
         self.CreateTime = params.get("CreateTime")
         self.AccessGroupIds = params.get("AccessGroupIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RestoreTask(AbstractModel):
@@ -1490,6 +1926,13 @@ class RestoreTask(AbstractModel):
         self.Days = params.get("Days")
         self.Status = params.get("Status")
         self.CreateTime = params.get("CreateTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Tag(AbstractModel):
@@ -1511,6 +1954,13 @@ class Tag(AbstractModel):
     def _deserialize(self, params):
         self.Key = params.get("Key")
         self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Transition(AbstractModel):
@@ -1531,4 +1981,11 @@ class Transition(AbstractModel):
 
     def _deserialize(self, params):
         self.Days = params.get("Days")
-        self.Type = params.get("Type")
\ No newline at end of file
+        self.Type = params.get("Type")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
